==> smallrye-jwt-2.3.1-sources.jar: io/smallrye/jwt/auth/mechanism/MechanismLogging_$logger.java <==
package io.smallrye.jwt.auth.mechanism;

import java.util.Locale;
import java.io.Serializable;
import org.jboss.logging.DelegatingBasicLogger;
import org.jboss.logging.BasicLogger;
import java.lang.Throwable;
import org.jboss.logging.Logger;


import static org.jboss.logging.Logger.Level.DEBUG;

/**
 * Warning this class consists of generated code.
 */
public class MechanismLogging_$logger extends DelegatingBasicLogger implements MechanismLogging, BasicLogger, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = MechanismLogging_$logger.class.getName();
    public MechanismLogging_$logger(final Logger log) {
        super(log);
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void success() {
        super.log.logf(FQCN, DEBUG, null, success$str());
    }
    protected String success$str() {
        return "SRJWT11000: Success";
    }
    @Override
    public final void unableToValidateBearerToken(final Throwable throwable) {
        super.log.logf(FQCN, DEBUG, throwable, unableToValidateBearerToken$str());
    }
    protected String unableToValidateBearerToken$str() {
        return "SRJWT11001: Unable to validate bearer token";
    }
    @Override
    public final void noUsableBearerTokenFound() {
        super.log.logf(FQCN, DEBUG, null, noUsableBearerTokenFound$str());
    }
    protected String noUsableBearerTokenFound$str() {
        return "SRJWT11002: No usable bearer token was found in the request, continuing unauthenticated";
    }
}

==> smallrye-jwt-2.4.4-sources.jar: io/smallrye/jwt/auth/mechanism/MechanismLogging_$logger.java <==
package io.smallrye.jwt.auth.mechanism;

import java.util.Locale;
import java.io.Serializable;
import org.jboss.logging.DelegatingBasicLogger;
import org.jboss.logging.BasicLogger;
import java.lang.Throwable;
import org.jboss.logging.Logger;


import static org.jboss.logging.Logger.Level.DEBUG;

/**
 * Warning this class consists of generated code.
 */
public class MechanismLogging_$logger extends DelegatingBasicLogger implements MechanismLogging, BasicLogger, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = MechanismLogging_$logger.class.getName();
    public MechanismLogging_$logger(final Logger log) {
        super(log);
    }
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void success() {
        super.log.logf(FQCN, DEBUG, null, success$str());
    }
    protected String success$str() {
        return "SRJWT11000: Success";
    }
    @Override
    public final void unableToValidateBearerToken(final Throwable throwable) {
        super.log.logf(FQCN, DEBUG, throwable, unableToValidateBearerToken$str());
    }
    protected String unableToValidateBearerToken$str() {
        return "SRJWT11001: Unable to validate bearer token";
    }
    @Override
    public final void noUsableBearerTokenFound() {
        super.log.logf(FQCN, DEBUG, null, noUsableBearerTokenFound$str());
    }
    protected String noUsableBearerTokenFound$str() {
        return "SRJWT11002: No usable bearer token was found in the request, continuing unauthenticated";
    }
    @Override
    public final void noUsableKey() {
        super.log.logf(FQCN, DEBUG, null, noUsableKey$str());
    }
    protected String noUsableKey$str() {
        return "SRJWT11003: Failed to resolve the key. Either corrupt or unavailable.";
    }
}
